@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li class="active">Notícias</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Notícias</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            @if (Check::can('news', 'create'))
                <a href="{{ route('manager.noticias.create') }}" class="btn btn-primary">Inserir nova notícia</a>
            @endif
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page=header -->

    {{ Msg::getAll() }}

     @if (Check::can('news', 'read'))
        <form action="{{ route('manager.noticias.index') }}" class="well form-inline" method="get" id="form-search">
            <div class="pull-left">
                <label>
                    <input type="text" name="title" placeholder="Título..." value="{{ Input::get('title') }}" maxlength="100" />
                </label>&nbsp;
            </div>

            <div class="pull-left">
                <label>
                    <select name="category_id" id="category_id">
                        <option value="">Categoria</option>
                        {{ $newsCategory->HTMLOptions(Input::get('category_id'), 'category') }}
                    </select>
                </label> &nbsp;&nbsp;
            </div>

            <div class="pull-left">
                <label class="checkbox" style="margin: 5px 0 0 0;">
                    <input type="checkbox" name="featured" value="1" {{ Input::get('featured') == 1 ? 'checked="checked"' : null }} /> &nbsp;
                    Apenas destaques &nbsp;&nbsp;
                </label>
            </div>

            <div class="pull-left">
                <button type="submit" class="btn btn-primary"><i class="icon-search icon-white"></i> Buscar</button>

                <a class="btn btn-primary" href="{{ route('manager.noticias.index') }}">
                    Limpar filtros
                </a>
            </div>

            <div class="clearfix"></div>
        </form>

        <table class="table table-bordered table-striped table-hover">
            <thead>
                <tr>
                    <th><a href="{{ order_by_link('manager.noticias.index', 'news.id', $params) }}" title="Ordenar pelo código">#</a></th>
                    <th><a href="{{ order_by_link('manager.noticias.index', 'news.title', $params) }}" title="Ordenar pelo título">Título</a></th>
                    <th><a href="{{ order_by_link('manager.noticias.index', 'news_categories.category', $params) }}" title="Ordenar pela categoria">Categoria</a></th>
                    <th><a href="{{ order_by_link('manager.noticias.index', 'news.date', $params) }}" title="Ordenar pela data">Data</a></th>
                    <th>Destaque</th>
                    <th>
                        <a href="{{ order_by_link('manager.noticias.index', 'news.order', $params) }}" title="Ordenar pela ordem">Ordem</a>
                        <button type="button" class="btn btn-mini" data-toggle="popover" data-content="Digite nos campos abaixo a ordem em que os destaques serão exibidos." data-original-title="Ordenação dos destaques">
                            <i class="icon-question-sign"></i>
                        </button>
                    </th>
                    <th>Ativo</th>
                    <th>Ação</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($notices as $news)
                    <tr>
                        <td>{{ $news->id }}</td>
                        <td>{{ $news->title }}</td>
                        <td>{{ $news->category }}</td>
                        <td>{{ date('d/m/y', strtotime(str_replace('-', '/', $news->date))) }}</td>
                        <td><input type="checkbox" value="1" data-id="{{ $news->id }}" class="js-update-featured" {{ $news->featured ? 'checked="checked"' : null }} /></td>
                        <td><input type="number" class="update-order js-update-order" data-id="{{ $news->id }}" value="{{ $news->order }}" {{ $news->featured ?: 'disabled="disabled"' }} min="1" step="1" style="width: 35px;" /></td>
                        <td><input type="checkbox" value="1" data-id="{{ $news->id }}" class="js-update-active" {{ $news->active ? 'checked="checked"' : null }} /></td>
                        <td>
                            <div class="btn-group">
                                <a href="{{ route('manager.midias.index', array($news->id, urlencode($news->getMediaModel()))) }}" class="btn btn-small" title="Editar">
                                    <i class="icon-camera"></i> fotos
                                </a>

                                @if (Check::can('news', 'update'))
                                    <a href="{{ route('manager.noticias.edit', $news->id) }}" class="btn btn-small" title="Editar">
                                        <i class="icon-pencil"></i> editar
                                    </a>
                                @endif

                                @if (Check::can('news', 'destroy'))
                                    <a href="{{ route('manager.noticias.destroy', $news->id) }}" class="btn btn-small" data-delete="true" title="Excluir">
                                        <i class="icon-trash"></i> excluir
                                    </a>
                                @endif
                            </div><!-- .btn-group -->
                        </td>
                    </tr>
                @endforeach
            </tbody>
        </table><!-- .table -->

        {{ $notices->appends(Input::except('page'))->links() }}
    @endif
@stop

@section('scripts')
    @parent

    <script type="text/javascript">
    (function() {
        window.App  = window.App || {};
        App.Manager = App.Manager || {};

        App.Manager.News = {
            init: function() {
                this.listenEventsActive();
                this.listenEventsFeature();
                this.bindUIEvents();

                $('[data-toggle="popover"]').popover();
            },

            bindUIEvents: function() {
                var _this = this;

                $('.js-update-order').on('blur', function(e) {
                    _this.updateOrder($(this));
                });
            },

            listenEventsActive: function() {
                var _this = this;

                $('.js-update-active').on('change', function(e) {
                    _this.updateActive($(this));
                });
            },

            updateActive: function($news) {
                var _this  = this,
                    id     = $news.data('id'),
                    active = $news.prop('checked') ? 1 : 0;

                $news.prop('disabled', true)

                $.post("{{ route('manager.noticias.index') }}/"+id+"/active", {
                    _method: 'put',
                    active: active
                }, function(result) {
                    $news.prop('disabled', false)
                });
            },

            listenEventsFeature: function() {
                var _this = this;

                $('.js-update-featured').on('change', function(e) {
                    _this.updateFeatured($(this));
                });
            },

            updateFeatured: function($news) {
                    var _this  = this,
                    id     = $news.data('id'),
                    featured = $news.prop('checked') ? 1 : 0;

                $news.prop('disabled', true)

                $.post("{{ route('manager.noticias.index') }}/"+id+"/featured", {
                    _method: 'put',
                    featured: featured
                }, function(result) {
                    $news.prop('disabled', false);

                    if ($news.prop('checked') === true) {
                        $news.parent().next('td').find('.js-update-order').prop('disabled', false).val(result.news.order);
                    } else {
                        $news.parent().next('td').find('.js-update-order').val('').prop('disabled', true);
                    }
                });
            },

            updateOrder: function($order) {
                $order.prop('disabled', true);

                $.post("{{ route('manager.noticias.index') }}/"+$order.data('id')+"/order", {
                    _method: 'put',
                    order: $order.val()
                }, function(result) {
                    $order.prop('disabled', false);
                });
            }
        }

        App.Manager.News.init();
    })();
    </script>
@stop

